@@ -1,6 +1,9 @@
 
 
 class Grid:
+    "https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.grid.html"
+    "https://matplotlib.org/stable/gallery/lines_bars_and_markers/linestyles.html"
+    "seolpyo_mplchart/_config/cursor.py"
     def __init__(self):
         self.visible = True
         self.linewidth = 0.7
@@ -12,6 +15,7 @@ class Grid:
 GRID = Grid()
 
 class TickData:
+    "https://matplotlib.org/stable/api/ticker_api.html"
     def __init__(self):
         self.edgecolor: str|tuple[float, float, float, float] = 'k'
         self.fontcolor: str|tuple[float, float, float, float] = 'k'
