@@ -1,6 +1,8 @@
 
 
 class CrossLineData:
+    "https://matplotlib.org/stable/gallery/lines_bars_and_markers/linestyles.html"
+    "https://matplotlib.org/stable/api/markers_api.html"
     def __init__(self):
         self.edgecolor = 'k'
         self.linewidth = 1
@@ -9,6 +11,8 @@ class CrossLineData:
 CROSSLINE = CrossLineData()
 
 class BBoxData:
+    "https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.FancyBboxPatch.html#matplotlib.patches.FancyBboxPatch"
+    "https://matplotlib.org/stable/gallery/lines_bars_and_markers/linestyles.html"
     def __init__(self):
         self.boxstyle = 'round'
         self.facecolor = 'w'
@@ -17,6 +21,7 @@ class BBoxData:
 BBOX = BBoxData()
 
 class Text:
+    "https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.text.html"
     def __init__(self):
         self.color = 'k'
         self.BBOX = BBOX
@@ -33,6 +38,7 @@ class Text:
 TEXT = Text()
 
 class Box:
+    "https://matplotlib.org/stable/gallery/lines_bars_and_markers/linestyles.html"
     def __init__(self):
         self.edgecolor = 'k'
         self.linewidth = 1.2
