@@ -1,11 +1,11 @@
 from .. import config
 from .figure import FIGURE, SliderFigureData
-from .nav import NAVIGATOR
+from .nav import NAV
 
 
 class SliderData:
     def __init__(self):
-        self.NAVIGATOR = NAVIGATOR
+        self.NAV = NAV
 
 SLIDER = SliderData()
 
