@@ -1,9 +1,10 @@
 
 
-class NavigatorData:
+class Nav:
     def __init__(self):
         self.edgecolor = '#2962FF'
         self.facecolor = '#0000002E'
+        self.alpha = 0.18
 
-NAVIGATOR = NavigatorData()
+NAV = Nav()
 
